@@ -66,6 +66,9 @@ def hands_parse(deal):
     hands = dict(zip_iterator)
     return hands #"\hand{}{94}{A}{AK87}"
 
+def bidding_parse(auction):
+    return(auction)
+
 def latex_suit(suit):
     # c => 
     for word, initial in {"S":"♠", "H":"♥","D":"♦","C":"♣" }.items():
@@ -94,7 +97,7 @@ def pbn_latex_auction(pbn):
         col += 1
     for one in filtered_auction:
         # print("aution:", one)
-        one = one.replace("!", '').replace("?","")
+        one = one.replace("!", '')
         table +="%s " % latex_suit(one)
         if col == 3:
             col = 0
@@ -164,8 +167,16 @@ def convert(block):
         if line.startswith("http"):
             xin2pbn.xin2pbn(line, PBN_FILE)
             pbn = pbn2html.get_from_pbn_file(PBN_FILE+".pbn")
+            print(pbn)
         elif line.startswith("auction"):
-            result += wrapper(pbn_latex_auction(pbn))
+            # handle part later to change pbn
+            newpbn=pbn.copy()
+            kv = line.split("=")
+            if len(kv) > 1:
+                auction=kv[1]
+                #print(newpbn["hands"])
+                newpbn["section_auction"] = bidding_parse(auction)
+            result += wrapper(pbn_latex_auction(newpbn))
         elif line.startswith("deal"):
             options = line.strip().split("|")
             cards = "NEWS"
